@@ -9,13 +9,13 @@ from optparse import OptionParser
 from convert import Converter
 from config import supported_formats
 
+from zopyx.convert import availableFormats
 
 def convert(options, args):
 
     if options.test_mode:
 
         import pkg_resources
-        from zopyx.convert import availableFormats
         print 'Entering testmode'
 
         for fn in ('test1.html', 'test2.html'):
@@ -27,6 +27,9 @@ def convert(options, args):
                 C = Converter(tmpf + '.html', verbose=True)
                 output_filename = C(format, output_filename=tmpf + '.' + format)
 
+    elif options.show_converters:
+        print 'Available converters: %s' % ','.join(availableFormats())
+
     else:
 
         for fn in args:
@@ -38,12 +41,15 @@ def convert(options, args):
 def main():
 
     parser = OptionParser()
-    parser.add_option('-v', '--verbose', dest='verbose', action="store_true",
+    parser.add_option('-v', '--verbose', dest='verbose', action='store_true',
                       default=False, help='verbose on')
 
     parser.add_option('-f', '--format', dest='format',
                       help='|'.join(supported_formats))
 
+    parser.add_option('-l', '--list-converters', action='store_true', dest='show_converters',
+                      default=False, help='show all available converters')
+
     parser.add_option('-o', '--output', dest='output_filename',
                       help='output filename')
 
